
// $Id: AlienCommandDialog.cpp,v 1.5 2012/07/23 13:52:03 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/


#include "AlienCommandDialog.h"
#include "AlienCommandModel.h"
#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "Icons.h"
#include "IconEngine.h"
#include "IconSize.h"
#include "TreeView.h"

#include <QtGui/QHeaderView>
#include <QtGui/QShortcut>

//__________________________________________________
AlienCommandDialog::AlienCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton ),
    model_( 0 )
{

    Debug::Throw( "AlienCommandDialog::AlienCommandDialog.\n" );
    setWindowTitle( "Command List - gridwatch" );

    // customize layout
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    setAttribute( Qt::WA_DeleteOnClose );
    setOptionName( "ALIEN_COMMAND_DIALOG" );
    mainLayout().addWidget( list_ = new TreeView(this) );

    list().header()->hide();
    list().setSortingEnabled( true );
    list().setIconSize( IconSize( IconSize::Medium ) );
    list().setSelectionMode( TreeView::ContiguousSelection );

    // abort action
    addAction( abortAction_ = new QAction( IconEngine::get( ICONS::KILL ), "&Abort", this ) );
    connect( abortAction_, SIGNAL( triggered( void ) ), SLOT( _abortCommands( void ) ) );
    abortAction_->setEnabled( false );

    list().menu().addAction( abortAction_ );
    list().menu().addMenu( new ColumnSortingMenu( &list().menu(), &list() ) );
    list().menu().addMenu( new ColumnSelectionMenu( &list().menu(), &list() ) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT( close() ) );

}

//__________________________________________________
void AlienCommandDialog::setModel( AlienCommandModel* model )
{
    list().setModel( model );
    list().setOptionName( "ALIEN_COMMAND_LIST" );
    connect( list().selectionModel(), SIGNAL( selectionChanged ( const QItemSelection &, const QItemSelection & ) ), SLOT( _updateActions() ) );

    // store/restore selection
    connect( model, SIGNAL( layoutAboutToBeChanged() ), SLOT( _storeSelection() ) );
    connect( model, SIGNAL( layoutChanged() ), SLOT( _restoreSelection() ) );

    model_ = model;

}

//__________________________________________________
void AlienCommandDialog::_updateActions( void )
{ abortAction_->setEnabled( !list().selectionModel()->selectedIndexes().isEmpty() ); }

//__________________________________________________
void AlienCommandDialog::_abortCommands( void )
{
    Debug::Throw( "AlienCommandDialog::_abortCommands.\n" );

    // check selection model
    if( !list().selectionModel() ) return;

    // emit abortCommand signals
    const AlienCommand::List commands( model_->get( list().selectionModel()->selectedIndexes() ) );
    emit commandsAborted( commands );

    // clear selection
    list().selectionModel()->clear();

}

//________________________________________
void AlienCommandDialog::_storeSelection( void )
{

    // clear
    model_->clearSelectedIndexes();

    // retrieve selected indexes in list
    QModelIndexList selectedIndexes( list().selectionModel()->selectedRows() );
    for( QModelIndexList::iterator iter = selectedIndexes.begin(); iter != selectedIndexes.end(); ++iter )
    {
        // check column
        if( !iter->column() == 0 ) continue;
        model_->setIndexSelected( *iter, true );
    }

}

//________________________________________
void AlienCommandDialog::_restoreSelection( void )
{

    QModelIndexList selectedIndexes( model_->selectedIndexes() );
    if( selectedIndexes.empty() ) list().selectionModel()->clear();
    else {

        list().selectionModel()->select( selectedIndexes.front(),  QItemSelectionModel::ClearAndSelect|QItemSelectionModel::Rows );
        for( QModelIndexList::const_iterator iter = selectedIndexes.begin(); iter != selectedIndexes.end(); ++iter )
        { list().selectionModel()->select( *iter, QItemSelectionModel::Select|QItemSelectionModel::Rows ); }

    }

    return;
}
