#ifndef JobInformationDialog_h
#define JobInformationDialog_h
// $Id: JobInformationDialog.h,v 1.17 2012/07/20 12:09:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "CustomDialog.h"
#include "FileRecord.h"
#include "Job.h"
#include "AlienCommand.h"
#include "Key.h"
#include "ListModel.h"
#include "OpenFileDialog.h"

#include <QtGui/QLabel>
#include <QtGui/QLayout>
#include <QtGui/QTabWidget>

class TextEditor;
class TreeView;
class GridLayout;

class JobInformationDialog: public CustomDialog, public BASE::Key
{

    Q_OBJECT

    public:

    //! constructor
    JobInformationDialog( QWidget* parent );

    //! destructor
    virtual ~JobInformationDialog( void )
    {}

    //! set job
    void setJob( const Job& );

    //! job
    const Job& job( void ) const
    { return job_; }

    signals:

    //! request command
    void commandRequested( const AlienCommand& );

    public slots:

    //! request update
    void requestUpdate( void );

    //! update
    void update( const Job&, const QString& = QString() );

    //! update jdl
    void updateJdl( const Job&, const QString& = QString() );

    //! update output files
    void updateFiles( const Job&, const QString&, const FileRecord::List& );

    //! command completed
    void commandCompleted( const AlienCommand& );

    protected slots:

    //! open or save
    void _openOrSave( unsigned int = OpenFileDialog::Any );

    //! open
    void _open( void );

    //! save as
    void _saveAs( File = File() );

    //! update actions
    void _updateActions( void );

    private:

    //! request job children
    void _requestChildren( void );

    //! request job trace
    void _requestTrace( void );

    //! request output files
    void _requestFiles( const QString& );

    //! request jdl
    void _requestJdl( void );

    //! recycle path, from job information
    QString _recyclePath( void ) const;

    private:

    //! install actions
    void _installActions( void );

    //! job
    Job job_;

    //! tab widget
    QTabWidget* tabWidget_;

    class Label: public QObject
    {
        public:

        //! constructor
        Label( const QString&, QWidget*, GridLayout* );

        //! constructor
        Label( const QString&, QWidget*, QBoxLayout* );

        //! destructor
        virtual ~Label( void )
        {}

        //! hide
        void setVisible( bool value )
        {
            key_->setVisible( value );
            value_->setVisible( value );
        }

        //! set text
        void setText( const QString& value )
        { value_->setText( value ); }

        //! get text
        QString text( void ) const
        { return value_->text(); }

        private:

        QLabel* key_;
        QLabel* value_;
    };

    //! id
    Label* idLabel_;

    //! parent
    Label* parentLabel_;

    //! user
    Label* userLabel_;

    //! location
    Label* locationLabel_;

    //! host
    Label* hostLabel_;

    //! command
    Label* commandLabel_;

    //! state
    Label* statusLabel_;

    //! submission time
    Label* submissionTimeLabel_;

    //! start time
    Label* startTimeLabel_;

    //! completion time
    Label* completionTimeLabel_;

    //! trace
    TextEditor* traceEditor_;

    //! jdl
    TextEditor* jdlEditor_;

    //! files container
    QWidget* filesContainer_;

    //! recycle path
    Label* pathLabel_;

    //! job output files
    TreeView* list_;

    //! open action
    QAction* openAction_;

    //! save as action
    QAction* saveAsAction_;

    //! model
    class Model: public ListModel<FileRecord>
    {

        public:

        //! number of columns
        enum { nColumns = 6 };

        //! column type enumeration
        enum ColumnType {
            PERMISSIONS,
            USER,
            GROUP,
            SIZE,
            CREATION,
            FILE
        };

        //!@name methods reimplemented from base class
        //@{

        // return data for a given index
        virtual QVariant data(const QModelIndex &index, int role) const;

        //! header data
        virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

        //! number of columns for a given index
        virtual int columnCount(const QModelIndex &parent = QModelIndex()) const
        { return nColumns; }

        //@}

        protected:

        //! sort
        virtual void _sort( int column, Qt::SortOrder order = Qt::AscendingOrder );

        private:

        //! used to sort IconCaches
        class SortFTor: public ItemModel::SortFTor
        {

            public:

            //! constructor
            SortFTor( const int& type, Qt::SortOrder order = Qt::AscendingOrder ):
                ItemModel::SortFTor( type, order )
            {}

            //! prediction
            bool operator() ( FileRecord, FileRecord ) const;

        };

        //! column titles
        static const QString columnTitles_[ nColumns ];

    };

    //! model
    Model model_;

    //! output directory
    QString outputDirectory_;

};

#endif
