// $Id: JobManagerFrame.cpp,v 1.7 2012/07/20 12:09:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file JobManagerFrame.cc
\brief customized QVBox to recieve close event
\author Hugo Pereira
\version $Revision: 1.7 $
\date $Date: 2012/07/20 12:09:21 $
*/

#include "JobManager.h"
#include "JobManagerFrame.h"
#include "SummaryFrame.h"

//___________________________________________
JobManagerFrame::JobManagerFrame( QWidget* parent ):
    QWidget( parent ),
    Counter( "JobManagerFrame" ),
    detached_( false )
{
    Debug::Throw( "JobManagerFrame::JobManagerFrame.\n" );

    // horizontal layout for summary frame and JobManager
    QHBoxLayout *hLayout( new QHBoxLayout() );
    hLayout->setMargin(0);
    hLayout->setSpacing(0);
    setLayout( hLayout );

    // sumary frame in a vertical layout
    QVBoxLayout *leftLayout( new QVBoxLayout() );
    leftLayout->setMargin(0);
    leftLayout->setSpacing(2);
    hLayout->addLayout( leftLayout );
    leftLayout->addWidget( summaryFrame_ = new SummaryFrame( this ), 0 );
    leftLayout->addStretch( 1 );

    // jobManager
    hLayout->addWidget( jobManager_ = new JobManager( this ), 1 );

    // connections
    connect( &summaryFrame(), SIGNAL( attached( bool ) ), SLOT( toggleAttached( bool ) ) );
    connect( &jobManager(), SIGNAL( jobListAvailable( QString, const JobSet&, bool ) ), &summaryFrame(), SLOT( updateJobList( QString, const JobSet&, bool ) ) );

    Debug::Throw( "JobManagerFrame::JobManagerFrame - done.\n" );

}

//________________________________________________________________________
JobManagerFrame::~JobManagerFrame( void )
{ Debug::Throw( "JobManagerFrame::~JobManagerFrame.\n" ); }

//________________________________________________________________________
void JobManagerFrame::setUser( const QString& value ) const
{
    jobManager().setUser( value );
    summaryFrame().setUser( value );
}
