// $Id: JobSet.cpp,v 1.9 2012/07/20 12:09:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*******************************************************************************/

#include "JobSet.h"
#include "XmlDef.h"

//____________________________________________________________
JobSet::JobSet( const QDomElement& element ):
    active_( false )
{
    Debug::Throw( "JobSet::Set (dom).\n" );

    // parse attributes
    QDomNamedNodeMap attributes( element.attributes() );
    for( unsigned int i=0; i<attributes.length(); i++ )
    {
        QDomAttr attribute( attributes.item( i ).toAttr() );
        if( attribute.isNull() ) continue;
        if( attribute.name() == XML::USER ) setOwner( attribute.value() );
        else if( attribute.name() == XML::ACTIVE ) setActive( attribute.value().toInt() );
        else Debug::Throw(0) << "JobSet::Set - unrecognized attribute " << attribute.name() << ".\n";

    }

    // parse children elements
    for(QDomNode childNode = element.firstChild(); !childNode.isNull(); childNode = childNode.nextSibling() )
    {
        QDomElement childElement = childNode.toElement();
        if( childElement.tagName() == XML::JOB ) insert( Job( childElement ) );
        else Debug::Throw(0) << "JobSet::Set - unrecognized child " << childElement.tagName() << ".\n";
    }

    // check children
    checkChildren();

}

//____________________________________________________________
QDomElement JobSet::domElement( QDomDocument& document ) const
{
    Debug::Throw( "JobSet::domElement.\n" );
    QDomElement out = document.createElement( XML::JOB_SET );

    // attributes
    if( !owner().isEmpty() ) out.setAttribute( XML::USER, owner() );
    if( isActive() ) out.setAttribute( XML::ACTIVE, "1" );

    // jobs
    foreach( const Job& job, *this )
    { out.appendChild( job.domElement( document ) ); }

    return out;
}

//____________________________________________________________
void JobSet::checkChildren( void )
{

    Debug::Throw( "JobSet::checkChildren" );
    typedef QMap<Job, JobSet> ChildSet;
    ChildSet children;

    foreach( const Job& job, *this )
    {

        // skip if parent not set
        if( !job.hasParent() ) continue;

        // find parent job
        iterator parentIter( find( Job().assign<int>( Job::ID, job.parentId() ) ) );
        if( parentIter == end() ) continue;

        // store in map
        children[*parentIter].insert( job );
    }

    // loop over childSets
    for( ChildSet::const_iterator iter = children.begin(); iter != children.end(); ++iter )
    {

        // find parent match in this set.
        iterator parentIter( find( iter.key() ) );
        Job parent( *parentIter );

        // remove from set and re-add with right child statistics
        erase( parentIter );
        insert( parent.setChildrenStatistics( JobStatistics( iter.value() ) ) );

    }

}
