
// $Id: JobStatistics.cpp,v 1.6 2011/11/10 23:06:18 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*******************************************************************************/

/*!
\file JobStatistics.cpp
\brief job statistics container
\author Hugo Pereira
\version $Revision: 1.6 $
\date $Date: 2011/11/10 23:06:18 $
*/

#include "JobStatistics.h"
#include "JobSet.h"
#include "XmlDef.h"

#include <algorithm>

//____________________________________________________________
JobStatistics::FieldNameVector &JobStatistics::_fieldNames( void )
{
    static FieldNameVector singleton( nFields, QString() );
    return singleton;
}

//____________________________________________________________
void JobStatistics::installFields( void )
{
    Debug::Throw( "Job::installFields.\n" );
    _setFieldName( TOTAL, "Total" );
    _setFieldName( COMPLETED, "Completed" );
    _setFieldName( RUNNING, "Running" );
    _setFieldName( PENDING, "Pending" );
    _setFieldName( FAILED, "Failed" );
    _setFieldName( UNKNOWN, "Unknown" );
    return;
}

//_________________________________________________
JobStatistics::JobStatistics( const QString& user ):
    Counter( "JobStatistics" ),
    time_( TimeStamp::now() ),
    fields_( nFields, 0 ),
    user_( user )
{ Debug::Throw( "JobStatistics::JobStatistics.\n" ); }


//_________________________________________________
JobStatistics::JobStatistics( const JobSet& jobs ):
    Counter( "JobStatistics" ),
    time_( TimeStamp::now() ),
    fields_( nFields, 0 )
{
    set( TOTAL, std::count_if( jobs.begin(), jobs.end(), Job::TotalFTor() ) );
    set( PENDING, std::count_if( jobs.begin(), jobs.end(), Job::PendingFTor() ) );
    set( RUNNING, std::count_if( jobs.begin(), jobs.end(), Job::RunningFTor() ) );
    set( COMPLETED, std::count_if( jobs.begin(), jobs.end(), Job::CompletedFTor() ) );
    set( FAILED, std::count_if( jobs.begin(), jobs.end(), Job::FailedFTor() ) );
    set( UNKNOWN,  get( TOTAL ) - get( PENDING ) - get( RUNNING ) - get( COMPLETED ) - get( FAILED ) );
}

//_________________________________________________
bool JobStatistics::operator == ( const JobStatistics& other ) const
{ return fields_ == other.fields_; }
