// $Id: JobStatusBar.cpp,v 1.1 2011/11/12 14:02:54 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file JobStatusBar.cpp
\brief  customized status bar for selection frame
\author Hugo Pereira
\version $Revision: 1.1 $
\date $Date: 2011/11/12 14:02:54 $
*/

#include "AnimatedStackedWidget.h"
#include "Debug.h"
#include "JobStatusBar.h"
#include "TransitionWidget.h"

#include <QtGui/QApplication>
#include <QtCore/QTimeLine>

//______________________________________________________
JobStatusBar::JobStatusBar( QWidget* parent ):
StatusBar( parent )
{
    Debug::Throw( "JobStatusBar::JobStatusBar.\n" );

    addPermanentWidget( stack_ = new AnimatedStackedWidget( this ), 1 );
    _stack().addWidget( label_ = new StatusBarLabel() );
    _stack().addWidget( progress_ = new QProgressBar() );

    // this is needed to have correct background for the label.
    label_->transitionWidget().setFlag( TransitionWidget::FROM_PARENT, true );

    // this is needed to make the transition visible.
    // It forces qApp::processEvents while transition is active
    connect( &progressBar(), SIGNAL( valueChanged( int ) ), this, SLOT( _update( void )) );
    addClock();

}

//______________________________________________________
void JobStatusBar::showProgressBar( void )
{

    Debug::Throw( "JobStatusBar::showProgressBar.\n" );
    progressBar().setFixedHeight( fontMetrics().lineSpacing() + 6 );
    _stack().setCurrentWidget( &progressBar() );

}

//______________________________________________________
void JobStatusBar::showLabel( void )
{
    Debug::Throw( "JobStatusBar::showLabel.\n" );
    _stack().setCurrentWidget( &_label() );
}


//______________________________________________________
void JobStatusBar::_update( void )
{
    // this hack is needed so that the transition is actually visible
    if( _stack().transitionWidget().timeLine().state() == QTimeLine::Running )
    { qApp->processEvents(); }
}
