#ifndef JobStatusBar_h
#define JobStatusBar_h

// $Id: JobStatusBar.h,v 1.1 2011/11/12 14:02:54 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file JobStatusBar.h
\brief customized status bar for selection frame
\author Hugo Pereira
\version $Revision: 1.1 $
\date $Date: 2011/11/12 14:02:54 $
*/

#include "StatusBar.h"
#include <QtGui/QProgressBar>

class AnimatedStackedWidget;

//! customized status bar for selection frame
class JobStatusBar: public StatusBar
{

    Q_OBJECT

        public:

        //! constructor
        JobStatusBar( QWidget* parent );

    //! progress bar
    QProgressBar& progressBar( void ) const
    {
        assert( progress_ );
        return *progress_;
    }

    //! retrieves label with given index
    virtual StatusBarLabel& label( const unsigned int& i = 0  ) const
    { return (i==0) ? _label():StatusBar::label(i); }

    public slots:

    //! show progress bar as visible widget
    void showProgressBar( void );

    //! show label as visible widget
    void showLabel( void );

    protected:

    //! stack widget
    AnimatedStackedWidget& _stack( void ) const
    {
        assert( stack_ );
        return *stack_;
    }

    //! label
    StatusBarLabel& _label( void ) const
    {
        assert( label_ );
        return *label_;
    }

    private slots:

    void _update( void );

    private:

    //! stack widget
    AnimatedStackedWidget* stack_;

    //! progress bar
    QProgressBar* progress_;

    //! label
    StatusBarLabel* label_;

};

#endif
