#ifndef SummaryFrame_h
#define SummaryFrame_h

// $Id: SummaryFrame.h,v 1.6 2012/07/20 12:09:21 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file    SummaryFrame.h
\brief   Job summary
\author  Hugo Pereira
\version $Revision: 1.6 $
\date    $Date: 2012/07/20 12:09:21 $
*/

#include "Counter.h"
#include "GridLayout.h"
#include "DockPanel.h"
#include "Job.h"
#include "JobSet.h"
#include "JobStatistics.h"

#include <QtGui/QLabel>

class SummaryBar;

class SummaryFrame: public DockPanel
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    SummaryFrame( QWidget* );

    //! selected user
    QString user( void ) const;

    public slots:

    //! update job set
    void updateJobList( QString, const JobSet& jobs, bool updateStamp )
    { _updateJobStatistics( JobStatistics( jobs ), updateStamp ); }

    //! clear
    void clear( void )
    { _updateJobStatistics( JobStatistics() ); }

    //! update user
    void setUser( const QString& );

    protected slots:

    //! toggle dock
    virtual void _toggleDock( void );

    protected:

    //! update labels from integer inputs
    void _updateJobStatistics( const JobStatistics&, bool = true );

    private:

    //! user
    QString userName_;

    //! user line_edit
    QLabel* user_;

    //! stores label and value
    class Label: public Counter
    {
        public:

        //! constructor
        Label( void ):
            Counter( "SummaryFrame::Label" ),
            autoHide_( true ),
            label_(0),
            valueLabel_(0),
            value_(0)
        {}

        //! constructor
        Label( QWidget*, GridLayout*, const QString& );

        //! destructor
        ~Label( void )
        {}

        //! autohide
        void setAutoHide( const bool& value )
        { autoHide_ = value; }

        //! set value
        bool set( const int& value );

        //! set visibility
        void setVisible( bool value )
        {
            label_->setVisible( value );
            valueLabel_->setVisible( value );
        }


        private:

        //! autohide
        bool autoHide_;

        //! name label
        QLabel* label_;

        //! value label
        QLabel* valueLabel_;

        //! integer value
        int value_;

    };

    //! total jobs label
    Label totalJobs_;

    //! pending jobs label
    Label pendingJobs_;

    //! running jobs label
    Label runningJobs_;

    //! failed jobs label
    Label failedJobs_;

    //! completed jobs label
    Label completedJobs_;

    //! unknown jobs label
    Label unknownJobs_;

    //! last update time
    QLabel* updated_;

    //! summary bar
    SummaryBar* summaryBar_;

};

#endif
